@@ -5,9 +5,8 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/achannarasappa/ticker/internal/asset"
 	c "github.com/achannarasappa/ticker/internal/common"
-	quoteYahoo "github.com/achannarasappa/ticker/internal/quote/yahoo"
+	"github.com/achannarasappa/ticker/internal/quote"
 	"github.com/achannarasappa/ticker/internal/ui/util"
 
 	"github.com/adrg/xdg"
@@ -47,11 +46,11 @@ func Run(uiStartFn func() error) func(*cobra.Command, []string) {
 func Validate(ctx *c.Context, options *Options, prevErr *error) func(*cobra.Command, []string) error {
 	return func(cmd *cobra.Command, args []string) error {
 
-		if prevErr != nil {
+		if prevErr != nil && *prevErr != nil {
 			return *prevErr
 		}
 
-		if len(ctx.Config.Watchlist) == 0 && len(options.Watchlist) == 0 && len(ctx.Config.Lots) == 0 {
+		if len(ctx.Config.Watchlist) == 0 && len(options.Watchlist) == 0 && len(ctx.Config.Lots) == 0 && len(ctx.Config.AssetGroup) == 0 {
 			return errors.New("Invalid config: No watchlist provided")
 		}
 
@@ -74,7 +73,8 @@ func GetContext(d c.Dependencies, options Options, configPath string) (c.Context
 	}
 
 	config = getConfig(config, options, *d.HttpClient)
-	reference, err = getReference(config, *d.HttpClient)
+	groups := getGroups(config)
+	reference, err = getReference(config, groups, *d.HttpClient)
 
 	if err != nil {
 		return c.Context{}, err
@@ -83,6 +83,7 @@ func GetContext(d c.Dependencies, options Options, configPath string) (c.Context
 	context := c.Context{
 		Reference: reference,
 		Config:    config,
+		Groups:    groups,
 	}
 
 	return context, nil
@@ -111,11 +112,9 @@ func readConfig(fs afero.Fs, configPathOption string) (c.Config, error) {
 	return config, nil
 }
 
-func getReference(config c.Config, client resty.Client) (c.Reference, error) {
+func getReference(config c.Config, assetGroups []c.AssetGroup, client resty.Client) (c.Reference, error) {
 
-	symbols := asset.GetSymbols(config)
-
-	currencyRates, err := quoteYahoo.GetCurrencyRates(client, symbols, config.Currency)
+	currencyRates, err := quote.GetAssetGroupsCurrencyRates(client, assetGroups, config.Currency)
 	styles := util.GetColorScheme(config.ColorScheme)
 
 	return c.Reference{
@@ -210,3 +209,53 @@ func getStringOption(cliValue string, configValue string) string {
 
 	return ""
 }
+
+func getGroups(config c.Config) []c.AssetGroup {
+
+	var groups []c.AssetGroup
+	var configAssetGroups []c.ConfigAssetGroup
+
+	if len(config.Watchlist) > 0 || len(config.Lots) > 0 {
+		configAssetGroups = append(configAssetGroups, c.ConfigAssetGroup{
+			Name:      "default",
+			Watchlist: config.Watchlist,
+			Holdings:  config.Lots,
+		})
+	}
+
+	configAssetGroups = append(configAssetGroups, config.AssetGroup...)
+
+	for _, configAssetGroup := range configAssetGroups {
+
+		symbols := make(map[string]bool)
+		symbolsUnique := make([]string, 0)
+
+		for _, symbol := range configAssetGroup.Watchlist {
+			if !symbols[symbol] {
+				symbols[symbol] = true
+				symbolsUnique = append(symbolsUnique, symbol)
+			}
+		}
+
+		for _, lot := range configAssetGroup.Holdings {
+			if !symbols[lot.Symbol] {
+				symbols[lot.Symbol] = true
+				symbolsUnique = append(symbolsUnique, lot.Symbol)
+			}
+		}
+
+		groups = append(groups, c.AssetGroup{
+			ConfigAssetGroup: configAssetGroup,
+			SymbolsBySource: []c.AssetGroupSymbolsBySource{
+				{
+					Source:  c.QuoteSourceYahoo,
+					Symbols: symbolsUnique,
+				},
+			},
+		})
+
+	}
+
+	return groups
+
+}
